@@ -22,7 +22,7 @@ $text = "Encrypt and Base64 this information, and we will make sure this is long
 
 #$text = "short text";
 $hce_md5 = Crypt::HCE_MD5->new("SharedSecret", "Random01,39j309ad");
-  
+
 $crypted = $hce_md5->hce_block_encrypt("Encrypt this information");
 $info = $hce_md5->hce_block_decrypt($crypted);
 if ($info eq "Encrypt this information") {
@@ -104,7 +104,7 @@ sub new {
 
 sub _initialize {
     my $self = shift;
-    
+
     if (!defined($self->{'Server'})) {
 	croak "Server not initialized properly : Server parameter missing";
     }
@@ -132,7 +132,7 @@ sub accept {
     my $self = shift;
     my ($time) = @_; # how long to wait
     my (@ready_to_read, $size);
-    
+
     @ready_to_read = $self->{'Select'}->can_read($time);
     $size = scalar(@ready_to_read);
     if ($size == 1) {
@@ -146,7 +146,7 @@ sub accept {
 
 sub close {
     my $self = shift;
-    
+
     $self->{'Connect'}->close;
     delete $self->{'Connect'};
     delete $self->{'HCE'};
@@ -181,12 +181,12 @@ sub send {
 sub recv {
     my $self = shift;
     my ($data, $dec_data, $fh);
-    
+
     if (!defined($self->{'Connect'})) {
 	croak "No Connection established: did you accept?";
     }
     $fh = $self->{'Connect'};
-    undef(@response);    
+    undef(@response);
     if (!defined($self->{'SKey'})) {
 	while (<$fh>) {
 	    chomp;
@@ -195,7 +195,7 @@ sub recv {
 	    last if ($_ eq '+END_OF_LIST');
 	    push @response, $_;
 	};
-	if (!defined(@response)) {
+	if (!(@response)) {
 	    return;
 	} else {
 	    return @response;
@@ -211,7 +211,7 @@ sub recv {
 	    last if ($dec_data eq "+END_OF_LIST");
 	    push @response, $dec_data;
 	};
-	if (!defined(@response)) {
+	if (!(@response)) {
 	    return;
 	} else {
 	    return @response;
@@ -279,7 +279,7 @@ sub _initialize {
     $self->{'HCE'} = Crypt::HCE_MD5->new($self->{'SKey'}, $self->{'RKey'});
     print { $self->{'Socket'} } "$self->{'RKey'}\n";
 }
-    
+
 sub send {
     my $self = shift;
     my @items = @_;
@@ -308,7 +308,7 @@ sub recv {
 
     if (defined($self->{'HCE'})) {
 	$data = "";
-	undef(@response);    
+	undef(@response);
 	while (<$fh>) {
 	    chomp;
 	    $data = 1;
@@ -321,14 +321,14 @@ sub recv {
 	if (!defined $data) {
 	    close ($self->{'Socket'});
 	    return $data;
-	    
+
 	} else {
 	    close ($self->{'Socket'});
 	    return @response;
 	};
     } else {
 	$data = "";
-	undef(@response);    
+	undef(@response);
 	while (<$fh>) {
 	    chomp;
 	    $data = 1;
